Class: DocuSign_Admin::GetUsersOptions
- Inherits:
-
Object
- Object
- DocuSign_Admin::GetUsersOptions
- Defined in:
- lib/docusign_admin/api/users_api.rb
Instance Attribute Summary collapse
-
#_end ⇒ Object
Index of the last item to include in the response.
-
#account_id ⇒ Object
Select users that are members of the specified account.
-
#email ⇒ Object
Email address of the desired user.
-
#email_user_name_like ⇒ Object
Selects users by pattern matching on the user’s email address.
-
#include_ds_groups ⇒ Object
Select users with groups the users belong to; account_id must be specified.
-
#include_license ⇒ Object
When true: additional details about the user’s license will be included in the response; account_id must be specified and the account must have an IAM plan with licenses.
-
#last_modified_since ⇒ Object
Select users whose data have been modified since the date specified; account_id or organization_reserved_domain_id must be specified.
-
#membership_status ⇒ Object
Select users based on membership status.
-
#organization_reserved_domain_id ⇒ Object
Select users that are in the specified domain.
-
#start ⇒ Object
Index of first item to include in the response Default value: 0.
-
#status ⇒ Object
Select users based on user status.
-
#take ⇒ Object
Page size of the response Default value: 20.
Class Method Summary collapse
Instance Attribute Details
#_end ⇒ Object
Index of the last item to include in the response. Ignored if ‘take’ parameter is specfied
63 64 65 |
# File 'lib/docusign_admin/api/users_api.rb', line 63 def _end @_end end |
#account_id ⇒ Object
Select users that are members of the specified account. At least one of email, account_id or organization_reserved_domain_id must be specified.
78 79 80 |
# File 'lib/docusign_admin/api/users_api.rb', line 78 def account_id @account_id end |
#email ⇒ Object
Email address of the desired user. At least one of email, account_id or organization_reserved_domain_id must be specified.
66 67 68 |
# File 'lib/docusign_admin/api/users_api.rb', line 66 def email @email end |
#email_user_name_like ⇒ Object
Selects users by pattern matching on the user’s email address
69 70 71 |
# File 'lib/docusign_admin/api/users_api.rb', line 69 def email_user_name_like @email_user_name_like end |
#include_ds_groups ⇒ Object
Select users with groups the users belong to; account_id must be specified. The organization must have the entitlement AllowMultiApplication enabled.
87 88 89 |
# File 'lib/docusign_admin/api/users_api.rb', line 87 def include_ds_groups @include_ds_groups end |
#include_license ⇒ Object
When true: additional details about the user’s license will be included in the response; account_id must be specified and the account must have an IAM plan with licenses.
90 91 92 |
# File 'lib/docusign_admin/api/users_api.rb', line 90 def include_license @include_license end |
#last_modified_since ⇒ Object
Select users whose data have been modified since the date specified; account_id or organization_reserved_domain_id must be specified.
84 85 86 |
# File 'lib/docusign_admin/api/users_api.rb', line 84 def last_modified_since @last_modified_since end |
#membership_status ⇒ Object
Select users based on membership status
75 76 77 |
# File 'lib/docusign_admin/api/users_api.rb', line 75 def membership_status @membership_status end |
#organization_reserved_domain_id ⇒ Object
Select users that are in the specified domain. At least one of email, account_id or organization_reserved_domain_id must be specified.
81 82 83 |
# File 'lib/docusign_admin/api/users_api.rb', line 81 def organization_reserved_domain_id @organization_reserved_domain_id end |
#start ⇒ Object
Index of first item to include in the response Default value: 0
57 58 59 |
# File 'lib/docusign_admin/api/users_api.rb', line 57 def start @start end |
#status ⇒ Object
Select users based on user status
72 73 74 |
# File 'lib/docusign_admin/api/users_api.rb', line 72 def status @status end |
#take ⇒ Object
Page size of the response Default value: 20
60 61 62 |
# File 'lib/docusign_admin/api/users_api.rb', line 60 def take @take end |
Class Method Details
.default ⇒ Object
92 93 94 |
# File 'lib/docusign_admin/api/users_api.rb', line 92 def self.default @@default ||= GetUsersOptions.new end |