Class: DocuSign_Admin::OrganizationsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/docusign_admin/api/organizations_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = OrganizationsApi.default) ⇒ OrganizationsApi

Returns a new instance of OrganizationsApi.



20
21
22
# File 'lib/docusign_admin/api/organizations_api.rb', line 20

def initialize(api_client = OrganizationsApi.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



18
19
20
# File 'lib/docusign_admin/api/organizations_api.rb', line 18

def api_client
  @api_client
end

Instance Method Details

#redact_individual_user_data(organization_id, request_model) ⇒ IndividualUserDataRedactionResponse

Redacts membership and user data for users in an organization. Required scopes: user_data_redact

Parameters:

  • The organization ID Guid

  • The request body describing the users and memberships to be redacted

Returns:



29
30
31
32
# File 'lib/docusign_admin/api/organizations_api.rb', line 29

def redact_individual_user_data(organization_id, request_model)
  data, _status_code, _headers = redact_individual_user_data_with_http_info(organization_id,  request_model)
  return data
end

#redact_individual_user_data_with_http_info(organization_id, request_model) ⇒ Array<(IndividualUserDataRedactionResponse, Fixnum, Hash)>

Redacts membership and user data for users in an organization. Required scopes: user_data_redact

Parameters:

  • The organization ID Guid

  • The request body describing the users and memberships to be redacted

Returns:

  • IndividualUserDataRedactionResponse data, response status code and response headers



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/docusign_admin/api/organizations_api.rb', line 39

def redact_individual_user_data_with_http_info(organization_id, request_model)
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: OrganizationsApi.redact_individual_user_data ..."
  end
  # verify the required parameter 'organization_id' is set
  fail ArgumentError, "Missing the required parameter 'organization_id' when calling OrganizationsApi.redact_individual_user_data" if organization_id.nil?
  # verify the required parameter 'request_model' is set
  fail ArgumentError, "Missing the required parameter 'request_model' when calling OrganizationsApi.redact_individual_user_data" if request_model.nil?
  # resource path
  local_var_path = "/v2/data_redaction/organizations/{organizationId}/user".sub('{format}','json').sub('{' + 'organizationId' + '}', organization_id.to_s)

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(request_model)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'IndividualUserDataRedactionResponse')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OrganizationsApi#redact_individual_user_data\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end