Class: DocuSign_Admin::UserDrilldownResponse
- Inherits:
-
Object
- Object
- DocuSign_Admin::UserDrilldownResponse
- Defined in:
- lib/docusign_admin/models/user_drilldown_response.rb
Instance Attribute Summary collapse
-
#allow_extend_org_admin_rights_to_self ⇒ Object
Returns the value of attribute allow_extend_org_admin_rights_to_self.
-
#allow_two_step_verification_snooze ⇒ Object
Returns the value of attribute allow_two_step_verification_snooze.
-
#created_on ⇒ Object
Returns the value of attribute created_on.
-
#default_account_id ⇒ Object
Returns the value of attribute default_account_id.
-
#default_account_name ⇒ Object
Returns the value of attribute default_account_name.
-
#device_verification_enabled ⇒ Object
Returns the value of attribute device_verification_enabled.
-
#federated_status ⇒ Object
Returns the value of attribute federated_status.
-
#first_name ⇒ Object
Returns the value of attribute first_name.
-
#id ⇒ Object
Returns the value of attribute id.
-
#identities ⇒ Object
Returns the value of attribute identities.
-
#is_managed_by_scim ⇒ Object
Returns the value of attribute is_managed_by_scim.
-
#is_organization_admin ⇒ Object
Returns the value of attribute is_organization_admin.
-
#language_culture ⇒ Object
Returns the value of attribute language_culture.
-
#last_login ⇒ Object
Returns the value of attribute last_login.
-
#last_name ⇒ Object
Returns the value of attribute last_name.
-
#memberships ⇒ Object
Returns the value of attribute memberships.
-
#require_two_step_verification ⇒ Object
Returns the value of attribute require_two_step_verification.
-
#selected_languages ⇒ Object
Returns the value of attribute selected_languages.
-
#site_id ⇒ Object
Returns the value of attribute site_id.
-
#site_name ⇒ Object
Returns the value of attribute site_name.
-
#user_name ⇒ Object
Returns the value of attribute user_name.
-
#user_status ⇒ Object
Returns the value of attribute user_status.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UserDrilldownResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ UserDrilldownResponse
Initializes the object
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 118 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'site_id') self.site_id = attributes[:'site_id'] end if attributes.has_key?(:'site_name') self.site_name = attributes[:'site_name'] end if attributes.has_key?(:'user_name') self.user_name = attributes[:'user_name'] end if attributes.has_key?(:'first_name') self.first_name = attributes[:'first_name'] end if attributes.has_key?(:'last_name') self.last_name = attributes[:'last_name'] end if attributes.has_key?(:'user_status') self.user_status = attributes[:'user_status'] end if attributes.has_key?(:'default_account_id') self.default_account_id = attributes[:'default_account_id'] end if attributes.has_key?(:'default_account_name') self.default_account_name = attributes[:'default_account_name'] end if attributes.has_key?(:'language_culture') self.language_culture = attributes[:'language_culture'] end if attributes.has_key?(:'selected_languages') self.selected_languages = attributes[:'selected_languages'] end if attributes.has_key?(:'federated_status') self.federated_status = attributes[:'federated_status'] end if attributes.has_key?(:'is_organization_admin') self.is_organization_admin = attributes[:'is_organization_admin'] end if attributes.has_key?(:'created_on') self.created_on = attributes[:'created_on'] end if attributes.has_key?(:'last_login') self.last_login = attributes[:'last_login'] end if attributes.has_key?(:'memberships') if (value = attributes[:'memberships']).is_a?(Array) self.memberships = value end end if attributes.has_key?(:'identities') if (value = attributes[:'identities']).is_a?(Array) self.identities = value end end if attributes.has_key?(:'device_verification_enabled') self.device_verification_enabled = attributes[:'device_verification_enabled'] end if attributes.has_key?(:'require_two_step_verification') self.require_two_step_verification = attributes[:'require_two_step_verification'] end if attributes.has_key?(:'allow_two_step_verification_snooze') self.allow_two_step_verification_snooze = attributes[:'allow_two_step_verification_snooze'] end if attributes.has_key?(:'allow_extend_org_admin_rights_to_self') self.allow_extend_org_admin_rights_to_self = attributes[:'allow_extend_org_admin_rights_to_self'] end if attributes.has_key?(:'is_managed_by_scim') self.is_managed_by_scim = attributes[:'is_managed_by_scim'] end end |
Instance Attribute Details
#allow_extend_org_admin_rights_to_self ⇒ Object
Returns the value of attribute allow_extend_org_admin_rights_to_self.
56 57 58 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 56 def allow_extend_org_admin_rights_to_self @allow_extend_org_admin_rights_to_self end |
#allow_two_step_verification_snooze ⇒ Object
Returns the value of attribute allow_two_step_verification_snooze.
54 55 56 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 54 def allow_two_step_verification_snooze @allow_two_step_verification_snooze end |
#created_on ⇒ Object
Returns the value of attribute created_on.
42 43 44 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 42 def created_on @created_on end |
#default_account_id ⇒ Object
Returns the value of attribute default_account_id.
30 31 32 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 30 def default_account_id @default_account_id end |
#default_account_name ⇒ Object
Returns the value of attribute default_account_name.
32 33 34 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 32 def default_account_name @default_account_name end |
#device_verification_enabled ⇒ Object
Returns the value of attribute device_verification_enabled.
50 51 52 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 50 def device_verification_enabled @device_verification_enabled end |
#federated_status ⇒ Object
Returns the value of attribute federated_status.
38 39 40 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 38 def federated_status @federated_status end |
#first_name ⇒ Object
Returns the value of attribute first_name.
24 25 26 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 24 def first_name @first_name end |
#id ⇒ Object
Returns the value of attribute id.
16 17 18 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 16 def id @id end |
#identities ⇒ Object
Returns the value of attribute identities.
48 49 50 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 48 def identities @identities end |
#is_managed_by_scim ⇒ Object
Returns the value of attribute is_managed_by_scim.
58 59 60 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 58 def is_managed_by_scim @is_managed_by_scim end |
#is_organization_admin ⇒ Object
Returns the value of attribute is_organization_admin.
40 41 42 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 40 def is_organization_admin @is_organization_admin end |
#language_culture ⇒ Object
Returns the value of attribute language_culture.
34 35 36 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 34 def language_culture @language_culture end |
#last_login ⇒ Object
Returns the value of attribute last_login.
44 45 46 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 44 def last_login @last_login end |
#last_name ⇒ Object
Returns the value of attribute last_name.
26 27 28 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 26 def last_name @last_name end |
#memberships ⇒ Object
Returns the value of attribute memberships.
46 47 48 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 46 def memberships @memberships end |
#require_two_step_verification ⇒ Object
Returns the value of attribute require_two_step_verification.
52 53 54 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 52 def require_two_step_verification @require_two_step_verification end |
#selected_languages ⇒ Object
Returns the value of attribute selected_languages.
36 37 38 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 36 def selected_languages @selected_languages end |
#site_id ⇒ Object
Returns the value of attribute site_id.
18 19 20 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 18 def site_id @site_id end |
#site_name ⇒ Object
Returns the value of attribute site_name.
20 21 22 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 20 def site_name @site_name end |
#user_name ⇒ Object
Returns the value of attribute user_name.
22 23 24 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 22 def user_name @user_name end |
#user_status ⇒ Object
Returns the value of attribute user_status.
28 29 30 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 28 def user_status @user_status end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 61 def self.attribute_map { :'id' => :'id', :'site_id' => :'site_id', :'site_name' => :'site_name', :'user_name' => :'user_name', :'first_name' => :'first_name', :'last_name' => :'last_name', :'user_status' => :'user_status', :'default_account_id' => :'default_account_id', :'default_account_name' => :'default_account_name', :'language_culture' => :'language_culture', :'selected_languages' => :'selected_languages', :'federated_status' => :'federated_status', :'is_organization_admin' => :'is_organization_admin', :'created_on' => :'created_on', :'last_login' => :'last_login', :'memberships' => :'memberships', :'identities' => :'identities', :'device_verification_enabled' => :'device_verification_enabled', :'require_two_step_verification' => :'require_two_step_verification', :'allow_two_step_verification_snooze' => :'allow_two_step_verification_snooze', :'allow_extend_org_admin_rights_to_self' => :'allow_extend_org_admin_rights_to_self', :'is_managed_by_scim' => :'is_managed_by_scim' } end |
.swagger_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 89 def self.swagger_types { :'id' => :'String', :'site_id' => :'Integer', :'site_name' => :'String', :'user_name' => :'String', :'first_name' => :'String', :'last_name' => :'String', :'user_status' => :'String', :'default_account_id' => :'String', :'default_account_name' => :'String', :'language_culture' => :'String', :'selected_languages' => :'String', :'federated_status' => :'String', :'is_organization_admin' => :'BOOLEAN', :'created_on' => :'DateTime', :'last_login' => :'DateTime', :'memberships' => :'Array<MembershipResponse>', :'identities' => :'Array<UserIdentityResponse>', :'device_verification_enabled' => :'BOOLEAN', :'require_two_step_verification' => :'BOOLEAN', :'allow_two_step_verification_snooze' => :'BOOLEAN', :'allow_extend_org_admin_rights_to_self' => :'BOOLEAN', :'is_managed_by_scim' => :'BOOLEAN' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 232 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && site_id == o.site_id && site_name == o.site_name && user_name == o.user_name && first_name == o.first_name && last_name == o.last_name && user_status == o.user_status && default_account_id == o.default_account_id && default_account_name == o.default_account_name && language_culture == o.language_culture && selected_languages == o.selected_languages && federated_status == o.federated_status && is_organization_admin == o.is_organization_admin && created_on == o.created_on && last_login == o.last_login && memberships == o.memberships && identities == o.identities && device_verification_enabled == o.device_verification_enabled && require_two_step_verification == o.require_two_step_verification && allow_two_step_verification_snooze == o.allow_two_step_verification_snooze && allow_extend_org_admin_rights_to_self == o.allow_extend_org_admin_rights_to_self && is_managed_by_scim == o.is_managed_by_scim end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 295 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = DocuSign_Admin.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 361 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 274 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
261 262 263 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 261 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
267 268 269 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 267 def hash [id, site_id, site_name, user_name, first_name, last_name, user_status, default_account_id, default_account_name, language_culture, selected_languages, federated_status, is_organization_admin, created_on, last_login, memberships, identities, device_verification_enabled, require_two_step_verification, allow_two_step_verification_snooze, allow_extend_org_admin_rights_to_self, is_managed_by_scim].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
219 220 221 222 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 219 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
341 342 343 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 341 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
347 348 349 350 351 352 353 354 355 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 347 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
335 336 337 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 335 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
226 227 228 |
# File 'lib/docusign_admin/models/user_drilldown_response.rb', line 226 def valid? true end |