Class: DocuSign_Admin::OrganizationUserResponse
- Inherits:
-
Object
- Object
- DocuSign_Admin::OrganizationUserResponse
- Defined in:
- lib/docusign_admin/models/organization_user_response.rb
Instance Attribute Summary collapse
-
#closed_on ⇒ Object
Returns the value of attribute closed_on.
-
#created_on ⇒ Object
Returns the value of attribute created_on.
-
#ds_groups ⇒ Object
Returns the value of attribute ds_groups.
-
#email ⇒ Object
Returns the value of attribute email.
-
#first_name ⇒ Object
Returns the value of attribute first_name.
-
#id ⇒ Object
Returns the value of attribute id.
-
#is_managed_by_scim ⇒ Object
Returns the value of attribute is_managed_by_scim.
-
#is_membership_managed_by_scim ⇒ Object
Returns the value of attribute is_membership_managed_by_scim.
-
#last_name ⇒ Object
Returns the value of attribute last_name.
-
#license_type ⇒ Object
Returns the value of attribute license_type.
-
#membership_closed_on ⇒ Object
Returns the value of attribute membership_closed_on.
-
#membership_created_on ⇒ Object
Returns the value of attribute membership_created_on.
-
#membership_id ⇒ Object
Returns the value of attribute membership_id.
-
#membership_status ⇒ Object
Returns the value of attribute membership_status.
-
#plan_name ⇒ Object
Returns the value of attribute plan_name.
-
#subscription_id ⇒ Object
Returns the value of attribute subscription_id.
-
#user_name ⇒ Object
Returns the value of attribute user_name.
-
#user_status ⇒ Object
Returns the value of attribute user_status.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OrganizationUserResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ OrganizationUserResponse
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 102 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'user_name') self.user_name = attributes[:'user_name'] end if attributes.has_key?(:'first_name') self.first_name = attributes[:'first_name'] end if attributes.has_key?(:'last_name') self.last_name = attributes[:'last_name'] end if attributes.has_key?(:'user_status') self.user_status = attributes[:'user_status'] end if attributes.has_key?(:'membership_status') self.membership_status = attributes[:'membership_status'] end if attributes.has_key?(:'email') self.email = attributes[:'email'] end if attributes.has_key?(:'created_on') self.created_on = attributes[:'created_on'] end if attributes.has_key?(:'closed_on') self.closed_on = attributes[:'closed_on'] end if attributes.has_key?(:'membership_created_on') self.membership_created_on = attributes[:'membership_created_on'] end if attributes.has_key?(:'membership_closed_on') self.membership_closed_on = attributes[:'membership_closed_on'] end if attributes.has_key?(:'ds_groups') if (value = attributes[:'ds_groups']).is_a?(Array) self.ds_groups = value end end if attributes.has_key?(:'membership_id') self.membership_id = attributes[:'membership_id'] end if attributes.has_key?(:'is_membership_managed_by_scim') self.is_membership_managed_by_scim = attributes[:'is_membership_managed_by_scim'] end if attributes.has_key?(:'is_managed_by_scim') self.is_managed_by_scim = attributes[:'is_managed_by_scim'] end if attributes.has_key?(:'license_type') self.license_type = attributes[:'license_type'] end if attributes.has_key?(:'subscription_id') self.subscription_id = attributes[:'subscription_id'] end if attributes.has_key?(:'plan_name') self.plan_name = attributes[:'plan_name'] end end |
Instance Attribute Details
#closed_on ⇒ Object
Returns the value of attribute closed_on.
32 33 34 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 32 def closed_on @closed_on end |
#created_on ⇒ Object
Returns the value of attribute created_on.
30 31 32 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 30 def created_on @created_on end |
#ds_groups ⇒ Object
Returns the value of attribute ds_groups.
38 39 40 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 38 def ds_groups @ds_groups end |
#email ⇒ Object
Returns the value of attribute email.
28 29 30 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 28 def email @email end |
#first_name ⇒ Object
Returns the value of attribute first_name.
20 21 22 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 20 def first_name @first_name end |
#id ⇒ Object
Returns the value of attribute id.
16 17 18 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 16 def id @id end |
#is_managed_by_scim ⇒ Object
Returns the value of attribute is_managed_by_scim.
44 45 46 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 44 def is_managed_by_scim @is_managed_by_scim end |
#is_membership_managed_by_scim ⇒ Object
Returns the value of attribute is_membership_managed_by_scim.
42 43 44 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 42 def is_membership_managed_by_scim @is_membership_managed_by_scim end |
#last_name ⇒ Object
Returns the value of attribute last_name.
22 23 24 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 22 def last_name @last_name end |
#license_type ⇒ Object
Returns the value of attribute license_type.
46 47 48 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 46 def license_type @license_type end |
#membership_closed_on ⇒ Object
Returns the value of attribute membership_closed_on.
36 37 38 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 36 def membership_closed_on @membership_closed_on end |
#membership_created_on ⇒ Object
Returns the value of attribute membership_created_on.
34 35 36 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 34 def membership_created_on @membership_created_on end |
#membership_id ⇒ Object
Returns the value of attribute membership_id.
40 41 42 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 40 def membership_id @membership_id end |
#membership_status ⇒ Object
Returns the value of attribute membership_status.
26 27 28 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 26 def membership_status @membership_status end |
#plan_name ⇒ Object
Returns the value of attribute plan_name.
50 51 52 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 50 def plan_name @plan_name end |
#subscription_id ⇒ Object
Returns the value of attribute subscription_id.
48 49 50 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 48 def subscription_id @subscription_id end |
#user_name ⇒ Object
Returns the value of attribute user_name.
18 19 20 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 18 def user_name @user_name end |
#user_status ⇒ Object
Returns the value of attribute user_status.
24 25 26 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 24 def user_status @user_status end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 53 def self.attribute_map { :'id' => :'id', :'user_name' => :'user_name', :'first_name' => :'first_name', :'last_name' => :'last_name', :'user_status' => :'user_status', :'membership_status' => :'membership_status', :'email' => :'email', :'created_on' => :'created_on', :'closed_on' => :'closed_on', :'membership_created_on' => :'membership_created_on', :'membership_closed_on' => :'membership_closed_on', :'ds_groups' => :'ds_groups', :'membership_id' => :'membership_id', :'is_membership_managed_by_scim' => :'is_membership_managed_by_scim', :'is_managed_by_scim' => :'is_managed_by_scim', :'license_type' => :'license_type', :'subscription_id' => :'subscription_id', :'plan_name' => :'plan_name' } end |
.swagger_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 77 def self.swagger_types { :'id' => :'String', :'user_name' => :'String', :'first_name' => :'String', :'last_name' => :'String', :'user_status' => :'String', :'membership_status' => :'String', :'email' => :'String', :'created_on' => :'DateTime', :'closed_on' => :'DateTime', :'membership_created_on' => :'DateTime', :'membership_closed_on' => :'DateTime', :'ds_groups' => :'Array<DSGroupResponse>', :'membership_id' => :'String', :'is_membership_managed_by_scim' => :'BOOLEAN', :'is_managed_by_scim' => :'BOOLEAN', :'license_type' => :'String', :'subscription_id' => :'String', :'plan_name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 198 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && user_name == o.user_name && first_name == o.first_name && last_name == o.last_name && user_status == o.user_status && membership_status == o.membership_status && email == o.email && created_on == o.created_on && closed_on == o.closed_on && membership_created_on == o.membership_created_on && membership_closed_on == o.membership_closed_on && ds_groups == o.ds_groups && membership_id == o.membership_id && is_membership_managed_by_scim == o.is_membership_managed_by_scim && is_managed_by_scim == o.is_managed_by_scim && license_type == o.license_type && subscription_id == o.subscription_id && plan_name == o.plan_name end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 257 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = DocuSign_Admin.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 323 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 236 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
223 224 225 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 223 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
229 230 231 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 229 def hash [id, user_name, first_name, last_name, user_status, membership_status, email, created_on, closed_on, membership_created_on, membership_closed_on, ds_groups, membership_id, is_membership_managed_by_scim, is_managed_by_scim, license_type, subscription_id, plan_name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
185 186 187 188 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 185 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
303 304 305 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 303 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
309 310 311 312 313 314 315 316 317 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 309 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
297 298 299 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 297 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
192 193 194 |
# File 'lib/docusign_admin/models/organization_user_response.rb', line 192 def valid? true end |